#
# spec file for package python-yaql
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global oldpython python
Name:           python-yaql
Version:        1.1.3
Release:        bp154.1.32
Summary:        YAQL - Yet Another Query Language
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://launchpad.net/yaql
Source0:        https://files.pythonhosted.org/packages/source/y/yaql/yaql-1.1.3.tar.gz
BuildRequires:  openstack-macros
# for testing
BuildRequires:  python2-Sphinx
BuildRequires:  python2-fixtures
BuildRequires:  python2-oslosphinx
BuildRequires:  python2-pbr
BuildRequires:  python2-ply
BuildRequires:  python2-python-dateutil
BuildRequires:  python2-python-subunit
BuildRequires:  python2-six
BuildRequires:  python2-testrepository
BuildRequires:  python2-testscenarios
BuildRequires:  python2-testtools
BuildRequires:  python3-Sphinx
BuildRequires:  python3-fixtures
BuildRequires:  python3-oslosphinx
BuildRequires:  python3-pbr
BuildRequires:  python3-ply
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-python-subunit
BuildRequires:  python3-six
BuildRequires:  python3-testrepository
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
Requires:       python-Babel
Requires:       python-ply
Requires:       python-python-dateutil
Requires:       python-six
Conflicts:      %{oldpython}-yaql < %version-%release
BuildArch:      noarch
%if 0%{?suse_version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
%else
# on RDO, update-alternatives is in chkconfig
Requires(post): chkconfig
Requires(postun): chkconfig
%endif
%python_subpackages

%description
YAQL (Yet Another Query Language) is an embeddable and extensible query
language, that allows performing complex queries against arbitrary objects. It
has a vast and comprehensive standard library of frequently used querying
functions and can be extend even further with user-specified functions. YAQL is
written in python and is distributed via PyPI.

%prep
%autosetup -p1 -n yaql-1.1.3
%py_req_cleanup

%build
%{python_build}

%install
%{python_install}
%python_clone -a %{buildroot}%{_bindir}/yaql

%post
%{python_install_alternative yaql}

%postun
%python_uninstall_alternative yaql

%check
%{python_expand rm -rf .testrepository
$python setup.py testr
}

%files %{python_files}
%license LICENSE
%doc ChangeLog README.rst
%python_alternative %{_bindir}/yaql
%{python_sitelib}/yaql
%{python_sitelib}/yaql*.egg-info

%changelog
* Wed Oct  9 2019 Thomas Bechtold <tbechtold@suse.com>
- Cleanup specfile
* Mon Apr  8 2019 Dirk Mueller <dmueller@suse.com>
- switch to stable/stein spec template
* Mon Sep  3 2018 dmueller@suse.com
- switch to stable/rocky spec template
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Sat Aug  5 2017 tbechtold@suse.com
- switch to stable/pike version
* Wed Jun  7 2017 cloud-devel@suse.de
- update to version 1.1.3
  - Refactor datetime.datetime usage to defined DATETIME_TYPE
  - Use reno for releasenotes
  - [docs] Docstrings for branching YAQL functions
  - YAQL autodoc script
  - [docs] Docstrings for strings YAQL functions
  - Pass re.VERBOSE explicitly
  - [docs] Docstrings for queries YAQL functions
  - Added engine options to disable input/output data conversion
  - Use __slots__ for yaqltypes
  - [docs] Docstrings for system YAQL functions
  - [docs] Docstrings for common YAQL functions
  - Remove oslosphinx from sphinx extensions
  - Auto building of std library docs
  - Add help info to CLI options
  - Update tests of YAQL queries
  - Rename shiftBitsLeft and shiftBitsRight arguments
  - Don't include openstack/common in flake8 exclude list
  - Customizing and extending yaql documentation
  - Fix "indexOf", "lastIndexOf" methods length parameter usage
  - YAQL syntax documentation
  - Use modern PBR and hacking packages
  - Use __slots__ for Parameter/Function definition
  - Remove discover from test-requirements
  - [docs] Docstrings for date_time YAQL functions
  - [docs] Docstrings for legacy YAQL functions
  - [docs] Docstrings for math YAQL functions
  - Update flake8 ignore list
  - Improvements to yaql CLI
  - [docs] Docstrings for boolean YAQL functions
  - Add a test proving escaped back references work
  - groupBy() aggregator was fixed
  - Create child context in regex/search function
  - Drop MANIFEST.in - it's not needed by pbr
  - [docs] Docstrings for yaqlized YAQL functions
  - [docs] Docstrings for regex YAQL functions
  - Changed the home-page link
  - Replace ValueError with StopIteration in single() method
  - Use six.moves.input for Python 3 compatability
  - Enable release notes translation
  - [docs] Docstrings for collections YAQL functions
* Fri Feb 10 2017 tbechtold@suse.com
- Use spec from openstack/rpm-packaging project
- Add _service
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.1.1:
  * Fix string operators >= and <=
  * Extend .slice() method implementation to all Iterables
  * Fix typo in YAML example
  * Python 3 compatibility issues were fixed
* Thu May 26 2016 tbechtold@suse.com
- Initial packaging (version 1.1.0)
